==> img0ch-3.0.0.tar.bz2: img0ch/_template/zeromin2/upload_load_review.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/res_side_menu.cs" ?>

<div id="main">

<form id="threadLoadReviewForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:Subject ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=upload&amp;method=load_review&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;resno=<?cs var:html_escape(Resno) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">添付ファイルの評価管理</a>
</div>

<h1>添付ファイルの評価管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_upload_remove_review ?><div class="noticeSuccess" id="notify"><p>チェックされた評価を削除しました</p></div><?cs /if ?>
<?cs if:Done_upload_remove_all_review ?><div class="noticeSuccess" id="notify"><p>評価を全て削除しました</p></div><?cs /if ?>
<?cs if:Done_upload_load_review ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>対象の評価が選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<p>
<select name="method">
  <option value="remove_review">チェックされた評価のみを削除</option>
  <option value="remove_all_review">このレスの評価を全て削除</option>
</select>
<input type="submit" value="実行" />
</p>

<?cs if:PollForReviewCount ?>
<ul>
<?cs each:item = PollForReview ?><li><?cs if:DisplayPolledIP ?><input type="checkbox" name="id" value="<?cs var:html_escape(item.ip) ?>" />&nbsp;<?cs /if ?><?cs var:html_escape(item.comment) ?>&nbsp;(<?cs var:html_escape(item.reviewed) ?><?cs if:DisplayPolledIP ?>&nbsp;-&nbsp;<?cs var:html_escape(item.ip) ?><?cs /if ?>)</li><?cs /each ?>
</ul>
<?cs else ?>
<p><?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>に対する評価はありません。</p>
<?cs /if ?>

<h3>対象の添付ファイル</h3>
<p><?cs if:IsImage ?><img src="<?cs var:html_escape(FileURL) ?>" alt="<?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>" /><?cs else ?><a href="<?cs var:html_escape(FileURL) ?>"><?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>のダウンロード</a><?cs /if ?></p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="upload" />
<input type="hidden" name="method" value="load_review" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="resno" value="<?cs var:html_escape(Resno) ?>" />
<input type="hidden" name="tag" value="<?cs var:html_escape(PollForReviewTag) ?>" />
<input type="hidden" name="OK" value="load_review" />
<input type="hidden" name="NG" value="load_review" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.6.tar.bz2: img0ch/_template/zeromin2/upload_load_review.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/res_side_menu.cs" ?>

<div id="main">

<form id="threadLoadReviewForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(BBS_TITLE) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=load&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;option=l50&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(Subject) ?></a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=upload&amp;method=load_review&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;key=<?cs var:html_escape(KEY) ?>&amp;resno=<?cs var:html_escape(Resno) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">添付ファイルの評価管理</a>
</div>

<h1>添付ファイルの評価管理</h1>

<?cs if:Code0 ?>
<?cs if:Done_upload_remove_review ?><div class="noticeSuccess" id="notify"><p>チェックされた評価を削除しました</p></div><?cs /if ?>
<?cs if:Done_upload_remove_all_review ?><div class="noticeSuccess" id="notify"><p>評価を全て削除しました</p></div><?cs /if ?>
<?cs if:Done_upload_load_review ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>対象の評価が選択されていません</p></div><?cs /if ?>
<?cs /if ?>

<p>
<select name="method">
  <option value="remove_review">チェックされた評価のみを削除</option>
  <option value="remove_all_review">このレスの評価を全て削除</option>
</select>
<input type="submit" value="実行" />
</p>

<?cs if:PollForReviewCount ?>
<ul>
<?cs each:item = PollForReview ?><li><?cs if:DisplayPolledIP ?><input type="checkbox" name="id" value="<?cs var:html_escape(item.ip) ?>" />&nbsp;<?cs /if ?><?cs var:html_escape(item.comment) ?>&nbsp;(<?cs var:html_escape(item.reviewed) ?><?cs if:DisplayPolledIP ?>&nbsp;-&nbsp;<?cs var:html_escape(item.ip) ?><?cs /if ?>)</li><?cs /each ?>
</ul>
<?cs else ?>
<p><?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>に対する評価はありません。</p>
<?cs /if ?>

<h3>対象の添付ファイル</h3>
<p><?cs if:IsImage ?><img src="<?cs var:html_escape(FileURL) ?>" alt="<?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>" /><?cs else ?><a href="<?cs var:html_escape(FileURL) ?>"><?cs var:html_escape(Resno) ?>.<?cs var:html_escape(FileExtension) ?>のダウンロード</a><?cs /if ?></p>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="upload" />
<input type="hidden" name="method" value="load_review" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>" />
<input type="hidden" name="resno" value="<?cs var:html_escape(Resno) ?>" />
<input type="hidden" name="tag" value="<?cs var:html_escape(PollForReviewTag) ?>" />
<input type="hidden" name="OK" value="load_review" />
<input type="hidden" name="NG" value="load_review" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
